#
# spec file for package ghc-text-short
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name text-short
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.1.5
Release:        bp155.2.16
Summary:        Memory-efficient representation of Unicode text strings
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-binary-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-text-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-quickcheck-devel
%endif

%description
This package provides the 'ShortText' type which is suitable for keeping many
short strings in memory. This is similiar to how 'ShortByteString' relates to
'ByteString'.

The main difference between 'Text' and 'ShortText' is that 'ShortText' uses
UTF-8 instead of UTF-16 internally and also doesn't support zero-copy slicing
(thereby saving 2 words). Consequently, the memory footprint of a (boxed)
'ShortText' value is 4 words (2 words when unboxed) plus the length of the
UTF-8 encoded payload.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md

%changelog
* Sat Jan  1 2022 Peter Simons <psimons@suse.com>
- Update text-short to version 0.1.5.
  [#]# 0.1.5
  * text-2.0 support
* Tue Nov 16 2021 psimons@suse.com
- Update text-short to version 0.1.4 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Nov  1 2021 psimons@suse.com
- Update text-short to version 0.1.4 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Oct 12 2021 psimons@suse.com
- Update text-short to version 0.1.4.
  [#]# 0.1.4
  * Fix `fromString` for single character strings.
    https://github.com/haskell-hvr/text-short/issues/20
  * Add Template Haskell `Lift ShortText` instance.
* Fri Feb 19 2021 psimons@suse.com
- Update text-short to version 0.1.3 revision 3.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Mon Aug 31 2020 psimons@suse.com
- Update text-short to version 0.1.3 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun  9 2020 psimons@suse.com
- Add text-short at version 0.1.3.
